==> keyclic_sdk_api-1.31.2.tar.gz: lib/model/feedback_review_request_pagination.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  FeedbackReviewRequestCollection embedded = null;

  PaginationLinks links = null;

  FeedbackReviewRequestPagination();

  @override
  String toString() {
    return 'FeedbackReviewRequestPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  FeedbackReviewRequestPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new FeedbackReviewRequestCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      'embedded': embedded,
      'links': links
    };
  }

  static List<FeedbackReviewRequestPagination> listFromJson(
      List<dynamic> json) {
    return json == null
        ? new List<FeedbackReviewRequestPagination>()
        : json
            .map((value) => new FeedbackReviewRequestPagination.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, FeedbackReviewRequestPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackReviewRequestPagination.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/feedback_review_request_pagination.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  FeedbackReviewRequestCollection embedded = null;

  PaginationLinks links = null;

  FeedbackReviewRequestPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  @override
  String toString() {
    return 'FeedbackReviewRequestPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  FeedbackReviewRequestPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new FeedbackReviewRequestCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  static List<FeedbackReviewRequestPagination> listFromJson(
      List<dynamic> json) {
    return json == null
        ? new List<FeedbackReviewRequestPagination>()
        : json
            .map((value) => new FeedbackReviewRequestPagination.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, FeedbackReviewRequestPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackReviewRequestPagination.fromJson(value));
    }
    return map;
  }
}
